* [PATCH] USB: fix SB600 USB subsystem hang bug
@ 2008-11-25 7:12 Shane Huang
0 siblings, 0 replies; only message in thread
From: Shane Huang @ 2008-11-25 7:12 UTC (permalink / raw)
To: linux-usb, linux-kernel, greg
Cc: ralfconn, roman, Yang, Libin, Xu, Andiry, Huang, Shane
This patch is required for all AMD SB600 revisions to avoid USB subsystem hang
symptom. The USB subsystem hang symptom is observed when the system has
multiple USB devices connected to it. In some cases a USB hub may be required
to observe this symptom.
Reported in bugzilla as #11599, the similar patch for SB700 old revision is:
commit b09bc6cbae4dd3a2d35722668ef2c502a7b8b093
Reported-by: raffaele <ralfconn@tele2.it>
Tested-by: Roman Mamedov <roman@rm.pp.ru>
Signed-off-by: Shane Huang <shane.huang@amd.com>
diff -ruN a/drivers/usb/host/ehci-pci.c b/drivers/usb/host/ehci-pci.c
--- a/drivers/usb/host/ehci-pci.c 2008-11-25 18:49:51.000000000 +0800
+++ b/drivers/usb/host/ehci-pci.c 2008-11-25 18:49:55.000000000 +0800
@@ -169,18 +169,21 @@
}
break;
case PCI_VENDOR_ID_ATI:
/* SB700 old version has a bug in EHCI controller,
* which causes usb devices lose response in some cases.
*/
- if (pdev->device == 0x4396) {
+ if ((pdev->device == 0x4386) || (pdev->device == 0x4396)) {
p_smbus = pci_get_device(PCI_VENDOR_ID_ATI,
PCI_DEVICE_ID_ATI_SBX00_SMBUS,
NULL);
if (!p_smbus)
break;
rev = p_smbus->revision;
- if ((rev == 0x3a) || (rev == 0x3b)) {
+ if ((pdev->device == 0x4386) || (rev == 0x3a)
+ || (rev == 0x3b)) {
u8 tmp;
+ ehci_info(ehci, "applying AMD SB600/SB700 USB "
+ "freeze workaround\n");
pci_read_config_byte(pdev, 0x53, &tmp);
pci_write_config_byte(pdev, 0x53, tmp | (1<<3));
}
^ permalink raw reply [flat|nested] only message in thread
only message in thread, other threads:[~2008-11-25 7:13 UTC | newest]
Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-11-25 7:12 [PATCH] USB: fix SB600 USB subsystem hang bug Shane Huang
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
@@ -169,18 +169,21 @@
break;
case PCI_VENDOR_ID_ATI:
- /* SB700 old version has a bug in EHCI controller,
+ /* SB600 and old version of SB700 have a bug in EHCI controller,
* which causes usb devices lose response in some cases.
*/